# -*- coding: utf-8 -*-
# Generated by Django 1.9.7 on 2016-06-07 11:50
from __future__ import unicode_literals

import django.db.models.deletion
from django.db import migrations, models

from wagtailmetadata.utils import get_image_model_string

IMAGE_MODEL = get_image_model_string()


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmetadata', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sitemetadatapreferences',
            name='site_description',
            field=models.TextField(help_text='\n    This is the default description displayed when your page is shared on\n     social media or is found on search engines'),
        ),
        migrations.AlterField(
            model_name='sitemetadatapreferences',
            name='site_image',
            field=models.ForeignKey(blank=True, help_text='\n        This is the default image that will be shown when your page is\n         shared on social media or is found on search engines ', null=True, on_delete=django.db.models.deletion.SET_NULL, to=IMAGE_MODEL),
        ),
    ]
