# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-11-14 04:53
from __future__ import unicode_literals

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailmetadata', '0004_remove_sitemetadatapreferences'),
    ]

    operations = [
        migrations.CreateModel(
            name='MetadataSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('twitter_handle', models.CharField(blank=True, help_text='Not including the @ symbol', max_length=16, null=True)),
                ('fb_app_id', models.CharField(blank=True, max_length=128, null=True)),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
